# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NodeBalancerConfigArgs', 'NodeBalancerConfig']

@pulumi.input_type
class NodeBalancerConfigArgs:
    def __init__(__self__, *,
                 nodebalancer_id: pulumi.Input[_builtins.int],
                 algorithm: Optional[pulumi.Input[_builtins.str]] = None,
                 check: Optional[pulumi.Input[_builtins.str]] = None,
                 check_attempts: Optional[pulumi.Input[_builtins.int]] = None,
                 check_body: Optional[pulumi.Input[_builtins.str]] = None,
                 check_interval: Optional[pulumi.Input[_builtins.int]] = None,
                 check_passive: Optional[pulumi.Input[_builtins.bool]] = None,
                 check_path: Optional[pulumi.Input[_builtins.str]] = None,
                 check_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 cipher_suite: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 proxy_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_key: Optional[pulumi.Input[_builtins.str]] = None,
                 stickiness: Optional[pulumi.Input[_builtins.str]] = None,
                 udp_check_port: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a NodeBalancerConfig resource.
        :param pulumi.Input[_builtins.int] nodebalancer_id: The ID of the NodeBalancer to access.
               
               - - -
        :param pulumi.Input[_builtins.str] algorithm: What algorithm this NodeBalancer should use for routing traffic to backends. (`roundrobin`, `leastconn`, `source`)
        :param pulumi.Input[_builtins.str] check: The type of check to perform against backends to ensure they are serving requests. This is used to determine if backends are up or down. If none no check is performed. connection requires only a connection to the backend to succeed. http and http_body rely on the backend serving HTTP, and that the response returned matches what is expected. (`none`, `connection`, `http`, `http_body`)
        :param pulumi.Input[_builtins.int] check_attempts: How many times to attempt a check before considering a backend to be down. (1-30)
        :param pulumi.Input[_builtins.str] check_body: This value must be present in the response body of the check in order for it to pass. If this value is not present in the response body of a check request, the backend is considered to be down
        :param pulumi.Input[_builtins.int] check_interval: How often, in seconds, to check that backends are up and serving requests.
        :param pulumi.Input[_builtins.bool] check_passive: If true, any response from this backend with a 5xx status code will be enough for it to be considered unhealthy and taken out of rotation.
        :param pulumi.Input[_builtins.str] check_path: The URL path to check on each backend. If the backend does not respond to this request it is considered to be down.
        :param pulumi.Input[_builtins.int] check_timeout: How long, in seconds, to wait for a check attempt before considering it failed. (1-30)
        :param pulumi.Input[_builtins.str] cipher_suite: What ciphers to use for SSL connections served by this NodeBalancer. `legacy` is considered insecure and should only be used if necessary.
        :param pulumi.Input[_builtins.int] port: The TCP port this Config is for. These values must be unique across configs on a single NodeBalancer (you can't have two configs for port 80, for example). While some ports imply some protocols, no enforcement is done and you may configure your NodeBalancer however is useful to you. For example, while port 443 is generally used for HTTPS, you do not need SSL configured to have a NodeBalancer listening on port 443. (Defaults to 80)
        :param pulumi.Input[_builtins.str] protocol: The protocol this port is configured to serve. If this is set to https you must include an ssl_cert and an ssl_key. (`http`, `https`, `tcp`) (Defaults to `http`)
        :param pulumi.Input[_builtins.str] proxy_protocol: The version of ProxyProtocol to use for the underlying NodeBalancer. This requires protocol to be `tcp`. (`none`, `v1`, `v2`) (Defaults to `none`)
        :param pulumi.Input[_builtins.str] ssl_cert: The certificate this port is serving. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        :param pulumi.Input[_builtins.str] ssl_key: The private key corresponding to this port's certificate. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        :param pulumi.Input[_builtins.str] stickiness: Controls how session stickiness is handled on this port. (`none`, `table`, `http_cookie`)
        :param pulumi.Input[_builtins.int] udp_check_port: Specifies the port on the backend node used for active health checks, which may differ from the port serving traffic. Defaults to 80.
               
               * **NOTE: This argument may not be generally available.**
        """
        pulumi.set(__self__, "nodebalancer_id", nodebalancer_id)
        if algorithm is not None:
            pulumi.set(__self__, "algorithm", algorithm)
        if check is not None:
            pulumi.set(__self__, "check", check)
        if check_attempts is not None:
            pulumi.set(__self__, "check_attempts", check_attempts)
        if check_body is not None:
            pulumi.set(__self__, "check_body", check_body)
        if check_interval is not None:
            pulumi.set(__self__, "check_interval", check_interval)
        if check_passive is not None:
            pulumi.set(__self__, "check_passive", check_passive)
        if check_path is not None:
            pulumi.set(__self__, "check_path", check_path)
        if check_timeout is not None:
            pulumi.set(__self__, "check_timeout", check_timeout)
        if cipher_suite is not None:
            pulumi.set(__self__, "cipher_suite", cipher_suite)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if proxy_protocol is not None:
            pulumi.set(__self__, "proxy_protocol", proxy_protocol)
        if ssl_cert is not None:
            pulumi.set(__self__, "ssl_cert", ssl_cert)
        if ssl_key is not None:
            pulumi.set(__self__, "ssl_key", ssl_key)
        if stickiness is not None:
            pulumi.set(__self__, "stickiness", stickiness)
        if udp_check_port is not None:
            pulumi.set(__self__, "udp_check_port", udp_check_port)

    @_builtins.property
    @pulumi.getter(name="nodebalancerId")
    def nodebalancer_id(self) -> pulumi.Input[_builtins.int]:
        """
        The ID of the NodeBalancer to access.

        - - -
        """
        return pulumi.get(self, "nodebalancer_id")

    @nodebalancer_id.setter
    def nodebalancer_id(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "nodebalancer_id", value)

    @_builtins.property
    @pulumi.getter
    def algorithm(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        What algorithm this NodeBalancer should use for routing traffic to backends. (`roundrobin`, `leastconn`, `source`)
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "algorithm", value)

    @_builtins.property
    @pulumi.getter
    def check(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of check to perform against backends to ensure they are serving requests. This is used to determine if backends are up or down. If none no check is performed. connection requires only a connection to the backend to succeed. http and http_body rely on the backend serving HTTP, and that the response returned matches what is expected. (`none`, `connection`, `http`, `http_body`)
        """
        return pulumi.get(self, "check")

    @check.setter
    def check(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "check", value)

    @_builtins.property
    @pulumi.getter(name="checkAttempts")
    def check_attempts(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        How many times to attempt a check before considering a backend to be down. (1-30)
        """
        return pulumi.get(self, "check_attempts")

    @check_attempts.setter
    def check_attempts(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "check_attempts", value)

    @_builtins.property
    @pulumi.getter(name="checkBody")
    def check_body(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This value must be present in the response body of the check in order for it to pass. If this value is not present in the response body of a check request, the backend is considered to be down
        """
        return pulumi.get(self, "check_body")

    @check_body.setter
    def check_body(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "check_body", value)

    @_builtins.property
    @pulumi.getter(name="checkInterval")
    def check_interval(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        How often, in seconds, to check that backends are up and serving requests.
        """
        return pulumi.get(self, "check_interval")

    @check_interval.setter
    def check_interval(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "check_interval", value)

    @_builtins.property
    @pulumi.getter(name="checkPassive")
    def check_passive(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, any response from this backend with a 5xx status code will be enough for it to be considered unhealthy and taken out of rotation.
        """
        return pulumi.get(self, "check_passive")

    @check_passive.setter
    def check_passive(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "check_passive", value)

    @_builtins.property
    @pulumi.getter(name="checkPath")
    def check_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL path to check on each backend. If the backend does not respond to this request it is considered to be down.
        """
        return pulumi.get(self, "check_path")

    @check_path.setter
    def check_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "check_path", value)

    @_builtins.property
    @pulumi.getter(name="checkTimeout")
    def check_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        How long, in seconds, to wait for a check attempt before considering it failed. (1-30)
        """
        return pulumi.get(self, "check_timeout")

    @check_timeout.setter
    def check_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "check_timeout", value)

    @_builtins.property
    @pulumi.getter(name="cipherSuite")
    def cipher_suite(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        What ciphers to use for SSL connections served by this NodeBalancer. `legacy` is considered insecure and should only be used if necessary.
        """
        return pulumi.get(self, "cipher_suite")

    @cipher_suite.setter
    def cipher_suite(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cipher_suite", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The TCP port this Config is for. These values must be unique across configs on a single NodeBalancer (you can't have two configs for port 80, for example). While some ports imply some protocols, no enforcement is done and you may configure your NodeBalancer however is useful to you. For example, while port 443 is generally used for HTTPS, you do not need SSL configured to have a NodeBalancer listening on port 443. (Defaults to 80)
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The protocol this port is configured to serve. If this is set to https you must include an ssl_cert and an ssl_key. (`http`, `https`, `tcp`) (Defaults to `http`)
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter(name="proxyProtocol")
    def proxy_protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The version of ProxyProtocol to use for the underlying NodeBalancer. This requires protocol to be `tcp`. (`none`, `v1`, `v2`) (Defaults to `none`)
        """
        return pulumi.get(self, "proxy_protocol")

    @proxy_protocol.setter
    def proxy_protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "proxy_protocol", value)

    @_builtins.property
    @pulumi.getter(name="sslCert")
    def ssl_cert(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The certificate this port is serving. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        """
        return pulumi.get(self, "ssl_cert")

    @ssl_cert.setter
    def ssl_cert(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ssl_cert", value)

    @_builtins.property
    @pulumi.getter(name="sslKey")
    def ssl_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The private key corresponding to this port's certificate. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        """
        return pulumi.get(self, "ssl_key")

    @ssl_key.setter
    def ssl_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ssl_key", value)

    @_builtins.property
    @pulumi.getter
    def stickiness(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Controls how session stickiness is handled on this port. (`none`, `table`, `http_cookie`)
        """
        return pulumi.get(self, "stickiness")

    @stickiness.setter
    def stickiness(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "stickiness", value)

    @_builtins.property
    @pulumi.getter(name="udpCheckPort")
    def udp_check_port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the port on the backend node used for active health checks, which may differ from the port serving traffic. Defaults to 80.

        * **NOTE: This argument may not be generally available.**
        """
        return pulumi.get(self, "udp_check_port")

    @udp_check_port.setter
    def udp_check_port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "udp_check_port", value)


@pulumi.input_type
class _NodeBalancerConfigState:
    def __init__(__self__, *,
                 algorithm: Optional[pulumi.Input[_builtins.str]] = None,
                 check: Optional[pulumi.Input[_builtins.str]] = None,
                 check_attempts: Optional[pulumi.Input[_builtins.int]] = None,
                 check_body: Optional[pulumi.Input[_builtins.str]] = None,
                 check_interval: Optional[pulumi.Input[_builtins.int]] = None,
                 check_passive: Optional[pulumi.Input[_builtins.bool]] = None,
                 check_path: Optional[pulumi.Input[_builtins.str]] = None,
                 check_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 cipher_suite: Optional[pulumi.Input[_builtins.str]] = None,
                 node_statuses: Optional[pulumi.Input[Sequence[pulumi.Input['NodeBalancerConfigNodeStatusArgs']]]] = None,
                 nodebalancer_id: Optional[pulumi.Input[_builtins.int]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 proxy_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_commonname: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_fingerprint: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_key: Optional[pulumi.Input[_builtins.str]] = None,
                 stickiness: Optional[pulumi.Input[_builtins.str]] = None,
                 udp_check_port: Optional[pulumi.Input[_builtins.int]] = None,
                 udp_session_timeout: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering NodeBalancerConfig resources.
        :param pulumi.Input[_builtins.str] algorithm: What algorithm this NodeBalancer should use for routing traffic to backends. (`roundrobin`, `leastconn`, `source`)
        :param pulumi.Input[_builtins.str] check: The type of check to perform against backends to ensure they are serving requests. This is used to determine if backends are up or down. If none no check is performed. connection requires only a connection to the backend to succeed. http and http_body rely on the backend serving HTTP, and that the response returned matches what is expected. (`none`, `connection`, `http`, `http_body`)
        :param pulumi.Input[_builtins.int] check_attempts: How many times to attempt a check before considering a backend to be down. (1-30)
        :param pulumi.Input[_builtins.str] check_body: This value must be present in the response body of the check in order for it to pass. If this value is not present in the response body of a check request, the backend is considered to be down
        :param pulumi.Input[_builtins.int] check_interval: How often, in seconds, to check that backends are up and serving requests.
        :param pulumi.Input[_builtins.bool] check_passive: If true, any response from this backend with a 5xx status code will be enough for it to be considered unhealthy and taken out of rotation.
        :param pulumi.Input[_builtins.str] check_path: The URL path to check on each backend. If the backend does not respond to this request it is considered to be down.
        :param pulumi.Input[_builtins.int] check_timeout: How long, in seconds, to wait for a check attempt before considering it failed. (1-30)
        :param pulumi.Input[_builtins.str] cipher_suite: What ciphers to use for SSL connections served by this NodeBalancer. `legacy` is considered insecure and should only be used if necessary.
        :param pulumi.Input[Sequence[pulumi.Input['NodeBalancerConfigNodeStatusArgs']]] node_statuses: A structure containing information about the health of the backends for this port. This information is updated periodically as checks are performed against backends.
        :param pulumi.Input[_builtins.int] nodebalancer_id: The ID of the NodeBalancer to access.
               
               - - -
        :param pulumi.Input[_builtins.int] port: The TCP port this Config is for. These values must be unique across configs on a single NodeBalancer (you can't have two configs for port 80, for example). While some ports imply some protocols, no enforcement is done and you may configure your NodeBalancer however is useful to you. For example, while port 443 is generally used for HTTPS, you do not need SSL configured to have a NodeBalancer listening on port 443. (Defaults to 80)
        :param pulumi.Input[_builtins.str] protocol: The protocol this port is configured to serve. If this is set to https you must include an ssl_cert and an ssl_key. (`http`, `https`, `tcp`) (Defaults to `http`)
        :param pulumi.Input[_builtins.str] proxy_protocol: The version of ProxyProtocol to use for the underlying NodeBalancer. This requires protocol to be `tcp`. (`none`, `v1`, `v2`) (Defaults to `none`)
        :param pulumi.Input[_builtins.str] ssl_cert: The certificate this port is serving. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        :param pulumi.Input[_builtins.str] ssl_commonname: The read-only common name automatically derived from the SSL certificate assigned to this NodeBalancerConfig. Please refer to this field to verify that the appropriate certificate is assigned to your NodeBalancerConfig.
        :param pulumi.Input[_builtins.str] ssl_fingerprint: The read-only fingerprint automatically derived from the SSL certificate assigned to this NodeBalancerConfig. Please refer to this field to verify that the appropriate certificate is assigned to your NodeBalancerConfig.
        :param pulumi.Input[_builtins.str] ssl_key: The private key corresponding to this port's certificate. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        :param pulumi.Input[_builtins.str] stickiness: Controls how session stickiness is handled on this port. (`none`, `table`, `http_cookie`)
        :param pulumi.Input[_builtins.int] udp_check_port: Specifies the port on the backend node used for active health checks, which may differ from the port serving traffic. Defaults to 80.
               
               * **NOTE: This argument may not be generally available.**
        :param pulumi.Input[_builtins.int] udp_session_timeout: The read-only idle time in seconds after which a session that hasn’t received packets is destroyed.
        """
        if algorithm is not None:
            pulumi.set(__self__, "algorithm", algorithm)
        if check is not None:
            pulumi.set(__self__, "check", check)
        if check_attempts is not None:
            pulumi.set(__self__, "check_attempts", check_attempts)
        if check_body is not None:
            pulumi.set(__self__, "check_body", check_body)
        if check_interval is not None:
            pulumi.set(__self__, "check_interval", check_interval)
        if check_passive is not None:
            pulumi.set(__self__, "check_passive", check_passive)
        if check_path is not None:
            pulumi.set(__self__, "check_path", check_path)
        if check_timeout is not None:
            pulumi.set(__self__, "check_timeout", check_timeout)
        if cipher_suite is not None:
            pulumi.set(__self__, "cipher_suite", cipher_suite)
        if node_statuses is not None:
            pulumi.set(__self__, "node_statuses", node_statuses)
        if nodebalancer_id is not None:
            pulumi.set(__self__, "nodebalancer_id", nodebalancer_id)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if proxy_protocol is not None:
            pulumi.set(__self__, "proxy_protocol", proxy_protocol)
        if ssl_cert is not None:
            pulumi.set(__self__, "ssl_cert", ssl_cert)
        if ssl_commonname is not None:
            pulumi.set(__self__, "ssl_commonname", ssl_commonname)
        if ssl_fingerprint is not None:
            pulumi.set(__self__, "ssl_fingerprint", ssl_fingerprint)
        if ssl_key is not None:
            pulumi.set(__self__, "ssl_key", ssl_key)
        if stickiness is not None:
            pulumi.set(__self__, "stickiness", stickiness)
        if udp_check_port is not None:
            pulumi.set(__self__, "udp_check_port", udp_check_port)
        if udp_session_timeout is not None:
            pulumi.set(__self__, "udp_session_timeout", udp_session_timeout)

    @_builtins.property
    @pulumi.getter
    def algorithm(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        What algorithm this NodeBalancer should use for routing traffic to backends. (`roundrobin`, `leastconn`, `source`)
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "algorithm", value)

    @_builtins.property
    @pulumi.getter
    def check(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of check to perform against backends to ensure they are serving requests. This is used to determine if backends are up or down. If none no check is performed. connection requires only a connection to the backend to succeed. http and http_body rely on the backend serving HTTP, and that the response returned matches what is expected. (`none`, `connection`, `http`, `http_body`)
        """
        return pulumi.get(self, "check")

    @check.setter
    def check(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "check", value)

    @_builtins.property
    @pulumi.getter(name="checkAttempts")
    def check_attempts(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        How many times to attempt a check before considering a backend to be down. (1-30)
        """
        return pulumi.get(self, "check_attempts")

    @check_attempts.setter
    def check_attempts(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "check_attempts", value)

    @_builtins.property
    @pulumi.getter(name="checkBody")
    def check_body(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This value must be present in the response body of the check in order for it to pass. If this value is not present in the response body of a check request, the backend is considered to be down
        """
        return pulumi.get(self, "check_body")

    @check_body.setter
    def check_body(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "check_body", value)

    @_builtins.property
    @pulumi.getter(name="checkInterval")
    def check_interval(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        How often, in seconds, to check that backends are up and serving requests.
        """
        return pulumi.get(self, "check_interval")

    @check_interval.setter
    def check_interval(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "check_interval", value)

    @_builtins.property
    @pulumi.getter(name="checkPassive")
    def check_passive(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, any response from this backend with a 5xx status code will be enough for it to be considered unhealthy and taken out of rotation.
        """
        return pulumi.get(self, "check_passive")

    @check_passive.setter
    def check_passive(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "check_passive", value)

    @_builtins.property
    @pulumi.getter(name="checkPath")
    def check_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL path to check on each backend. If the backend does not respond to this request it is considered to be down.
        """
        return pulumi.get(self, "check_path")

    @check_path.setter
    def check_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "check_path", value)

    @_builtins.property
    @pulumi.getter(name="checkTimeout")
    def check_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        How long, in seconds, to wait for a check attempt before considering it failed. (1-30)
        """
        return pulumi.get(self, "check_timeout")

    @check_timeout.setter
    def check_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "check_timeout", value)

    @_builtins.property
    @pulumi.getter(name="cipherSuite")
    def cipher_suite(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        What ciphers to use for SSL connections served by this NodeBalancer. `legacy` is considered insecure and should only be used if necessary.
        """
        return pulumi.get(self, "cipher_suite")

    @cipher_suite.setter
    def cipher_suite(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cipher_suite", value)

    @_builtins.property
    @pulumi.getter(name="nodeStatuses")
    def node_statuses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NodeBalancerConfigNodeStatusArgs']]]]:
        """
        A structure containing information about the health of the backends for this port. This information is updated periodically as checks are performed against backends.
        """
        return pulumi.get(self, "node_statuses")

    @node_statuses.setter
    def node_statuses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NodeBalancerConfigNodeStatusArgs']]]]):
        pulumi.set(self, "node_statuses", value)

    @_builtins.property
    @pulumi.getter(name="nodebalancerId")
    def nodebalancer_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of the NodeBalancer to access.

        - - -
        """
        return pulumi.get(self, "nodebalancer_id")

    @nodebalancer_id.setter
    def nodebalancer_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "nodebalancer_id", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The TCP port this Config is for. These values must be unique across configs on a single NodeBalancer (you can't have two configs for port 80, for example). While some ports imply some protocols, no enforcement is done and you may configure your NodeBalancer however is useful to you. For example, while port 443 is generally used for HTTPS, you do not need SSL configured to have a NodeBalancer listening on port 443. (Defaults to 80)
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The protocol this port is configured to serve. If this is set to https you must include an ssl_cert and an ssl_key. (`http`, `https`, `tcp`) (Defaults to `http`)
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter(name="proxyProtocol")
    def proxy_protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The version of ProxyProtocol to use for the underlying NodeBalancer. This requires protocol to be `tcp`. (`none`, `v1`, `v2`) (Defaults to `none`)
        """
        return pulumi.get(self, "proxy_protocol")

    @proxy_protocol.setter
    def proxy_protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "proxy_protocol", value)

    @_builtins.property
    @pulumi.getter(name="sslCert")
    def ssl_cert(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The certificate this port is serving. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        """
        return pulumi.get(self, "ssl_cert")

    @ssl_cert.setter
    def ssl_cert(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ssl_cert", value)

    @_builtins.property
    @pulumi.getter(name="sslCommonname")
    def ssl_commonname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The read-only common name automatically derived from the SSL certificate assigned to this NodeBalancerConfig. Please refer to this field to verify that the appropriate certificate is assigned to your NodeBalancerConfig.
        """
        return pulumi.get(self, "ssl_commonname")

    @ssl_commonname.setter
    def ssl_commonname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ssl_commonname", value)

    @_builtins.property
    @pulumi.getter(name="sslFingerprint")
    def ssl_fingerprint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The read-only fingerprint automatically derived from the SSL certificate assigned to this NodeBalancerConfig. Please refer to this field to verify that the appropriate certificate is assigned to your NodeBalancerConfig.
        """
        return pulumi.get(self, "ssl_fingerprint")

    @ssl_fingerprint.setter
    def ssl_fingerprint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ssl_fingerprint", value)

    @_builtins.property
    @pulumi.getter(name="sslKey")
    def ssl_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The private key corresponding to this port's certificate. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        """
        return pulumi.get(self, "ssl_key")

    @ssl_key.setter
    def ssl_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ssl_key", value)

    @_builtins.property
    @pulumi.getter
    def stickiness(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Controls how session stickiness is handled on this port. (`none`, `table`, `http_cookie`)
        """
        return pulumi.get(self, "stickiness")

    @stickiness.setter
    def stickiness(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "stickiness", value)

    @_builtins.property
    @pulumi.getter(name="udpCheckPort")
    def udp_check_port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the port on the backend node used for active health checks, which may differ from the port serving traffic. Defaults to 80.

        * **NOTE: This argument may not be generally available.**
        """
        return pulumi.get(self, "udp_check_port")

    @udp_check_port.setter
    def udp_check_port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "udp_check_port", value)

    @_builtins.property
    @pulumi.getter(name="udpSessionTimeout")
    def udp_session_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The read-only idle time in seconds after which a session that hasn’t received packets is destroyed.
        """
        return pulumi.get(self, "udp_session_timeout")

    @udp_session_timeout.setter
    def udp_session_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "udp_session_timeout", value)


@pulumi.type_token("linode:index/nodeBalancerConfig:NodeBalancerConfig")
class NodeBalancerConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 algorithm: Optional[pulumi.Input[_builtins.str]] = None,
                 check: Optional[pulumi.Input[_builtins.str]] = None,
                 check_attempts: Optional[pulumi.Input[_builtins.int]] = None,
                 check_body: Optional[pulumi.Input[_builtins.str]] = None,
                 check_interval: Optional[pulumi.Input[_builtins.int]] = None,
                 check_passive: Optional[pulumi.Input[_builtins.bool]] = None,
                 check_path: Optional[pulumi.Input[_builtins.str]] = None,
                 check_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 cipher_suite: Optional[pulumi.Input[_builtins.str]] = None,
                 nodebalancer_id: Optional[pulumi.Input[_builtins.int]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 proxy_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_key: Optional[pulumi.Input[_builtins.str]] = None,
                 stickiness: Optional[pulumi.Input[_builtins.str]] = None,
                 udp_check_port: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Provides a Linode NodeBalancer Config resource.  This can be used to create, modify, and delete Linodes NodeBalancer Configs.
        For more information, see [Getting Started with NodeBalancers](https://www.linode.com/docs/platform/nodebalancer/getting-started-with-nodebalancers/) and the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/post-node-balancer-config).

        ## Example Usage

        The following example shows how one might use this resource to configure a NodeBalancer Config attached to a Linode instance.

        ```python
        import pulumi
        import pulumi_linode as linode

        foobar = linode.NodeBalancer("foobar",
            label="mynodebalancer",
            region="us-east",
            client_conn_throttle=20)
        foofig = linode.NodeBalancerConfig("foofig",
            nodebalancer_id=foobar.id,
            port=8088,
            protocol="http",
            check="http",
            check_path="/foo",
            check_attempts=3,
            check_timeout=30,
            udp_check_port=12345,
            stickiness="http_cookie",
            algorithm="source")
        ```

        ## Import

        NodeBalancer Configs can be imported using the NodeBalancer `nodebalancer_id` followed by the NodeBalancer Config `id` separated by a comma, e.g.

        ```sh
        $ pulumi import linode:index/nodeBalancerConfig:NodeBalancerConfig http-foobar 1234567,7654321
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] algorithm: What algorithm this NodeBalancer should use for routing traffic to backends. (`roundrobin`, `leastconn`, `source`)
        :param pulumi.Input[_builtins.str] check: The type of check to perform against backends to ensure they are serving requests. This is used to determine if backends are up or down. If none no check is performed. connection requires only a connection to the backend to succeed. http and http_body rely on the backend serving HTTP, and that the response returned matches what is expected. (`none`, `connection`, `http`, `http_body`)
        :param pulumi.Input[_builtins.int] check_attempts: How many times to attempt a check before considering a backend to be down. (1-30)
        :param pulumi.Input[_builtins.str] check_body: This value must be present in the response body of the check in order for it to pass. If this value is not present in the response body of a check request, the backend is considered to be down
        :param pulumi.Input[_builtins.int] check_interval: How often, in seconds, to check that backends are up and serving requests.
        :param pulumi.Input[_builtins.bool] check_passive: If true, any response from this backend with a 5xx status code will be enough for it to be considered unhealthy and taken out of rotation.
        :param pulumi.Input[_builtins.str] check_path: The URL path to check on each backend. If the backend does not respond to this request it is considered to be down.
        :param pulumi.Input[_builtins.int] check_timeout: How long, in seconds, to wait for a check attempt before considering it failed. (1-30)
        :param pulumi.Input[_builtins.str] cipher_suite: What ciphers to use for SSL connections served by this NodeBalancer. `legacy` is considered insecure and should only be used if necessary.
        :param pulumi.Input[_builtins.int] nodebalancer_id: The ID of the NodeBalancer to access.
               
               - - -
        :param pulumi.Input[_builtins.int] port: The TCP port this Config is for. These values must be unique across configs on a single NodeBalancer (you can't have two configs for port 80, for example). While some ports imply some protocols, no enforcement is done and you may configure your NodeBalancer however is useful to you. For example, while port 443 is generally used for HTTPS, you do not need SSL configured to have a NodeBalancer listening on port 443. (Defaults to 80)
        :param pulumi.Input[_builtins.str] protocol: The protocol this port is configured to serve. If this is set to https you must include an ssl_cert and an ssl_key. (`http`, `https`, `tcp`) (Defaults to `http`)
        :param pulumi.Input[_builtins.str] proxy_protocol: The version of ProxyProtocol to use for the underlying NodeBalancer. This requires protocol to be `tcp`. (`none`, `v1`, `v2`) (Defaults to `none`)
        :param pulumi.Input[_builtins.str] ssl_cert: The certificate this port is serving. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        :param pulumi.Input[_builtins.str] ssl_key: The private key corresponding to this port's certificate. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        :param pulumi.Input[_builtins.str] stickiness: Controls how session stickiness is handled on this port. (`none`, `table`, `http_cookie`)
        :param pulumi.Input[_builtins.int] udp_check_port: Specifies the port on the backend node used for active health checks, which may differ from the port serving traffic. Defaults to 80.
               
               * **NOTE: This argument may not be generally available.**
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NodeBalancerConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Linode NodeBalancer Config resource.  This can be used to create, modify, and delete Linodes NodeBalancer Configs.
        For more information, see [Getting Started with NodeBalancers](https://www.linode.com/docs/platform/nodebalancer/getting-started-with-nodebalancers/) and the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/post-node-balancer-config).

        ## Example Usage

        The following example shows how one might use this resource to configure a NodeBalancer Config attached to a Linode instance.

        ```python
        import pulumi
        import pulumi_linode as linode

        foobar = linode.NodeBalancer("foobar",
            label="mynodebalancer",
            region="us-east",
            client_conn_throttle=20)
        foofig = linode.NodeBalancerConfig("foofig",
            nodebalancer_id=foobar.id,
            port=8088,
            protocol="http",
            check="http",
            check_path="/foo",
            check_attempts=3,
            check_timeout=30,
            udp_check_port=12345,
            stickiness="http_cookie",
            algorithm="source")
        ```

        ## Import

        NodeBalancer Configs can be imported using the NodeBalancer `nodebalancer_id` followed by the NodeBalancer Config `id` separated by a comma, e.g.

        ```sh
        $ pulumi import linode:index/nodeBalancerConfig:NodeBalancerConfig http-foobar 1234567,7654321
        ```

        :param str resource_name: The name of the resource.
        :param NodeBalancerConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NodeBalancerConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 algorithm: Optional[pulumi.Input[_builtins.str]] = None,
                 check: Optional[pulumi.Input[_builtins.str]] = None,
                 check_attempts: Optional[pulumi.Input[_builtins.int]] = None,
                 check_body: Optional[pulumi.Input[_builtins.str]] = None,
                 check_interval: Optional[pulumi.Input[_builtins.int]] = None,
                 check_passive: Optional[pulumi.Input[_builtins.bool]] = None,
                 check_path: Optional[pulumi.Input[_builtins.str]] = None,
                 check_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 cipher_suite: Optional[pulumi.Input[_builtins.str]] = None,
                 nodebalancer_id: Optional[pulumi.Input[_builtins.int]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 proxy_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_key: Optional[pulumi.Input[_builtins.str]] = None,
                 stickiness: Optional[pulumi.Input[_builtins.str]] = None,
                 udp_check_port: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NodeBalancerConfigArgs.__new__(NodeBalancerConfigArgs)

            __props__.__dict__["algorithm"] = algorithm
            __props__.__dict__["check"] = check
            __props__.__dict__["check_attempts"] = check_attempts
            __props__.__dict__["check_body"] = check_body
            __props__.__dict__["check_interval"] = check_interval
            __props__.__dict__["check_passive"] = check_passive
            __props__.__dict__["check_path"] = check_path
            __props__.__dict__["check_timeout"] = check_timeout
            __props__.__dict__["cipher_suite"] = cipher_suite
            if nodebalancer_id is None and not opts.urn:
                raise TypeError("Missing required property 'nodebalancer_id'")
            __props__.__dict__["nodebalancer_id"] = nodebalancer_id
            __props__.__dict__["port"] = port
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["proxy_protocol"] = proxy_protocol
            __props__.__dict__["ssl_cert"] = None if ssl_cert is None else pulumi.Output.secret(ssl_cert)
            __props__.__dict__["ssl_key"] = None if ssl_key is None else pulumi.Output.secret(ssl_key)
            __props__.__dict__["stickiness"] = stickiness
            __props__.__dict__["udp_check_port"] = udp_check_port
            __props__.__dict__["node_statuses"] = None
            __props__.__dict__["ssl_commonname"] = None
            __props__.__dict__["ssl_fingerprint"] = None
            __props__.__dict__["udp_session_timeout"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["sslCert", "sslKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(NodeBalancerConfig, __self__).__init__(
            'linode:index/nodeBalancerConfig:NodeBalancerConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            algorithm: Optional[pulumi.Input[_builtins.str]] = None,
            check: Optional[pulumi.Input[_builtins.str]] = None,
            check_attempts: Optional[pulumi.Input[_builtins.int]] = None,
            check_body: Optional[pulumi.Input[_builtins.str]] = None,
            check_interval: Optional[pulumi.Input[_builtins.int]] = None,
            check_passive: Optional[pulumi.Input[_builtins.bool]] = None,
            check_path: Optional[pulumi.Input[_builtins.str]] = None,
            check_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            cipher_suite: Optional[pulumi.Input[_builtins.str]] = None,
            node_statuses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NodeBalancerConfigNodeStatusArgs', 'NodeBalancerConfigNodeStatusArgsDict']]]]] = None,
            nodebalancer_id: Optional[pulumi.Input[_builtins.int]] = None,
            port: Optional[pulumi.Input[_builtins.int]] = None,
            protocol: Optional[pulumi.Input[_builtins.str]] = None,
            proxy_protocol: Optional[pulumi.Input[_builtins.str]] = None,
            ssl_cert: Optional[pulumi.Input[_builtins.str]] = None,
            ssl_commonname: Optional[pulumi.Input[_builtins.str]] = None,
            ssl_fingerprint: Optional[pulumi.Input[_builtins.str]] = None,
            ssl_key: Optional[pulumi.Input[_builtins.str]] = None,
            stickiness: Optional[pulumi.Input[_builtins.str]] = None,
            udp_check_port: Optional[pulumi.Input[_builtins.int]] = None,
            udp_session_timeout: Optional[pulumi.Input[_builtins.int]] = None) -> 'NodeBalancerConfig':
        """
        Get an existing NodeBalancerConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] algorithm: What algorithm this NodeBalancer should use for routing traffic to backends. (`roundrobin`, `leastconn`, `source`)
        :param pulumi.Input[_builtins.str] check: The type of check to perform against backends to ensure they are serving requests. This is used to determine if backends are up or down. If none no check is performed. connection requires only a connection to the backend to succeed. http and http_body rely on the backend serving HTTP, and that the response returned matches what is expected. (`none`, `connection`, `http`, `http_body`)
        :param pulumi.Input[_builtins.int] check_attempts: How many times to attempt a check before considering a backend to be down. (1-30)
        :param pulumi.Input[_builtins.str] check_body: This value must be present in the response body of the check in order for it to pass. If this value is not present in the response body of a check request, the backend is considered to be down
        :param pulumi.Input[_builtins.int] check_interval: How often, in seconds, to check that backends are up and serving requests.
        :param pulumi.Input[_builtins.bool] check_passive: If true, any response from this backend with a 5xx status code will be enough for it to be considered unhealthy and taken out of rotation.
        :param pulumi.Input[_builtins.str] check_path: The URL path to check on each backend. If the backend does not respond to this request it is considered to be down.
        :param pulumi.Input[_builtins.int] check_timeout: How long, in seconds, to wait for a check attempt before considering it failed. (1-30)
        :param pulumi.Input[_builtins.str] cipher_suite: What ciphers to use for SSL connections served by this NodeBalancer. `legacy` is considered insecure and should only be used if necessary.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NodeBalancerConfigNodeStatusArgs', 'NodeBalancerConfigNodeStatusArgsDict']]]] node_statuses: A structure containing information about the health of the backends for this port. This information is updated periodically as checks are performed against backends.
        :param pulumi.Input[_builtins.int] nodebalancer_id: The ID of the NodeBalancer to access.
               
               - - -
        :param pulumi.Input[_builtins.int] port: The TCP port this Config is for. These values must be unique across configs on a single NodeBalancer (you can't have two configs for port 80, for example). While some ports imply some protocols, no enforcement is done and you may configure your NodeBalancer however is useful to you. For example, while port 443 is generally used for HTTPS, you do not need SSL configured to have a NodeBalancer listening on port 443. (Defaults to 80)
        :param pulumi.Input[_builtins.str] protocol: The protocol this port is configured to serve. If this is set to https you must include an ssl_cert and an ssl_key. (`http`, `https`, `tcp`) (Defaults to `http`)
        :param pulumi.Input[_builtins.str] proxy_protocol: The version of ProxyProtocol to use for the underlying NodeBalancer. This requires protocol to be `tcp`. (`none`, `v1`, `v2`) (Defaults to `none`)
        :param pulumi.Input[_builtins.str] ssl_cert: The certificate this port is serving. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        :param pulumi.Input[_builtins.str] ssl_commonname: The read-only common name automatically derived from the SSL certificate assigned to this NodeBalancerConfig. Please refer to this field to verify that the appropriate certificate is assigned to your NodeBalancerConfig.
        :param pulumi.Input[_builtins.str] ssl_fingerprint: The read-only fingerprint automatically derived from the SSL certificate assigned to this NodeBalancerConfig. Please refer to this field to verify that the appropriate certificate is assigned to your NodeBalancerConfig.
        :param pulumi.Input[_builtins.str] ssl_key: The private key corresponding to this port's certificate. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        :param pulumi.Input[_builtins.str] stickiness: Controls how session stickiness is handled on this port. (`none`, `table`, `http_cookie`)
        :param pulumi.Input[_builtins.int] udp_check_port: Specifies the port on the backend node used for active health checks, which may differ from the port serving traffic. Defaults to 80.
               
               * **NOTE: This argument may not be generally available.**
        :param pulumi.Input[_builtins.int] udp_session_timeout: The read-only idle time in seconds after which a session that hasn’t received packets is destroyed.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NodeBalancerConfigState.__new__(_NodeBalancerConfigState)

        __props__.__dict__["algorithm"] = algorithm
        __props__.__dict__["check"] = check
        __props__.__dict__["check_attempts"] = check_attempts
        __props__.__dict__["check_body"] = check_body
        __props__.__dict__["check_interval"] = check_interval
        __props__.__dict__["check_passive"] = check_passive
        __props__.__dict__["check_path"] = check_path
        __props__.__dict__["check_timeout"] = check_timeout
        __props__.__dict__["cipher_suite"] = cipher_suite
        __props__.__dict__["node_statuses"] = node_statuses
        __props__.__dict__["nodebalancer_id"] = nodebalancer_id
        __props__.__dict__["port"] = port
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["proxy_protocol"] = proxy_protocol
        __props__.__dict__["ssl_cert"] = ssl_cert
        __props__.__dict__["ssl_commonname"] = ssl_commonname
        __props__.__dict__["ssl_fingerprint"] = ssl_fingerprint
        __props__.__dict__["ssl_key"] = ssl_key
        __props__.__dict__["stickiness"] = stickiness
        __props__.__dict__["udp_check_port"] = udp_check_port
        __props__.__dict__["udp_session_timeout"] = udp_session_timeout
        return NodeBalancerConfig(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def algorithm(self) -> pulumi.Output[_builtins.str]:
        """
        What algorithm this NodeBalancer should use for routing traffic to backends. (`roundrobin`, `leastconn`, `source`)
        """
        return pulumi.get(self, "algorithm")

    @_builtins.property
    @pulumi.getter
    def check(self) -> pulumi.Output[_builtins.str]:
        """
        The type of check to perform against backends to ensure they are serving requests. This is used to determine if backends are up or down. If none no check is performed. connection requires only a connection to the backend to succeed. http and http_body rely on the backend serving HTTP, and that the response returned matches what is expected. (`none`, `connection`, `http`, `http_body`)
        """
        return pulumi.get(self, "check")

    @_builtins.property
    @pulumi.getter(name="checkAttempts")
    def check_attempts(self) -> pulumi.Output[_builtins.int]:
        """
        How many times to attempt a check before considering a backend to be down. (1-30)
        """
        return pulumi.get(self, "check_attempts")

    @_builtins.property
    @pulumi.getter(name="checkBody")
    def check_body(self) -> pulumi.Output[_builtins.str]:
        """
        This value must be present in the response body of the check in order for it to pass. If this value is not present in the response body of a check request, the backend is considered to be down
        """
        return pulumi.get(self, "check_body")

    @_builtins.property
    @pulumi.getter(name="checkInterval")
    def check_interval(self) -> pulumi.Output[_builtins.int]:
        """
        How often, in seconds, to check that backends are up and serving requests.
        """
        return pulumi.get(self, "check_interval")

    @_builtins.property
    @pulumi.getter(name="checkPassive")
    def check_passive(self) -> pulumi.Output[_builtins.bool]:
        """
        If true, any response from this backend with a 5xx status code will be enough for it to be considered unhealthy and taken out of rotation.
        """
        return pulumi.get(self, "check_passive")

    @_builtins.property
    @pulumi.getter(name="checkPath")
    def check_path(self) -> pulumi.Output[_builtins.str]:
        """
        The URL path to check on each backend. If the backend does not respond to this request it is considered to be down.
        """
        return pulumi.get(self, "check_path")

    @_builtins.property
    @pulumi.getter(name="checkTimeout")
    def check_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        How long, in seconds, to wait for a check attempt before considering it failed. (1-30)
        """
        return pulumi.get(self, "check_timeout")

    @_builtins.property
    @pulumi.getter(name="cipherSuite")
    def cipher_suite(self) -> pulumi.Output[_builtins.str]:
        """
        What ciphers to use for SSL connections served by this NodeBalancer. `legacy` is considered insecure and should only be used if necessary.
        """
        return pulumi.get(self, "cipher_suite")

    @_builtins.property
    @pulumi.getter(name="nodeStatuses")
    def node_statuses(self) -> pulumi.Output[Sequence['outputs.NodeBalancerConfigNodeStatus']]:
        """
        A structure containing information about the health of the backends for this port. This information is updated periodically as checks are performed against backends.
        """
        return pulumi.get(self, "node_statuses")

    @_builtins.property
    @pulumi.getter(name="nodebalancerId")
    def nodebalancer_id(self) -> pulumi.Output[_builtins.int]:
        """
        The ID of the NodeBalancer to access.

        - - -
        """
        return pulumi.get(self, "nodebalancer_id")

    @_builtins.property
    @pulumi.getter
    def port(self) -> pulumi.Output[_builtins.int]:
        """
        The TCP port this Config is for. These values must be unique across configs on a single NodeBalancer (you can't have two configs for port 80, for example). While some ports imply some protocols, no enforcement is done and you may configure your NodeBalancer however is useful to you. For example, while port 443 is generally used for HTTPS, you do not need SSL configured to have a NodeBalancer listening on port 443. (Defaults to 80)
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[_builtins.str]:
        """
        The protocol this port is configured to serve. If this is set to https you must include an ssl_cert and an ssl_key. (`http`, `https`, `tcp`) (Defaults to `http`)
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter(name="proxyProtocol")
    def proxy_protocol(self) -> pulumi.Output[_builtins.str]:
        """
        The version of ProxyProtocol to use for the underlying NodeBalancer. This requires protocol to be `tcp`. (`none`, `v1`, `v2`) (Defaults to `none`)
        """
        return pulumi.get(self, "proxy_protocol")

    @_builtins.property
    @pulumi.getter(name="sslCert")
    def ssl_cert(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The certificate this port is serving. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        """
        return pulumi.get(self, "ssl_cert")

    @_builtins.property
    @pulumi.getter(name="sslCommonname")
    def ssl_commonname(self) -> pulumi.Output[_builtins.str]:
        """
        The read-only common name automatically derived from the SSL certificate assigned to this NodeBalancerConfig. Please refer to this field to verify that the appropriate certificate is assigned to your NodeBalancerConfig.
        """
        return pulumi.get(self, "ssl_commonname")

    @_builtins.property
    @pulumi.getter(name="sslFingerprint")
    def ssl_fingerprint(self) -> pulumi.Output[_builtins.str]:
        """
        The read-only fingerprint automatically derived from the SSL certificate assigned to this NodeBalancerConfig. Please refer to this field to verify that the appropriate certificate is assigned to your NodeBalancerConfig.
        """
        return pulumi.get(self, "ssl_fingerprint")

    @_builtins.property
    @pulumi.getter(name="sslKey")
    def ssl_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The private key corresponding to this port's certificate. This is not returned. If set, this field will come back as `<REDACTED>`. Please use the ssl_commonname and ssl_fingerprint to identify the certificate.
        """
        return pulumi.get(self, "ssl_key")

    @_builtins.property
    @pulumi.getter
    def stickiness(self) -> pulumi.Output[_builtins.str]:
        """
        Controls how session stickiness is handled on this port. (`none`, `table`, `http_cookie`)
        """
        return pulumi.get(self, "stickiness")

    @_builtins.property
    @pulumi.getter(name="udpCheckPort")
    def udp_check_port(self) -> pulumi.Output[_builtins.int]:
        """
        Specifies the port on the backend node used for active health checks, which may differ from the port serving traffic. Defaults to 80.

        * **NOTE: This argument may not be generally available.**
        """
        return pulumi.get(self, "udp_check_port")

    @_builtins.property
    @pulumi.getter(name="udpSessionTimeout")
    def udp_session_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        The read-only idle time in seconds after which a session that hasn’t received packets is destroyed.
        """
        return pulumi.get(self, "udp_session_timeout")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 api_ca_path: Optional[pulumi.Input[_builtins.str]] = None,
                 api_version: Optional[pulumi.Input[_builtins.str]] = None,
                 config_path: Optional[pulumi.Input[_builtins.str]] = None,
                 config_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_internal_cache: Optional[pulumi.Input[_builtins.bool]] = None,
                 event_poll_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 lke_event_poll_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 lke_node_ready_poll_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 max_retry_delay_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 min_retry_delay_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 obj_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 obj_bucket_force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 obj_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 obj_use_temp_keys: Optional[pulumi.Input[_builtins.bool]] = None,
                 skip_implicit_reboots: Optional[pulumi.Input[_builtins.bool]] = None,
                 skip_instance_delete_poll: Optional[pulumi.Input[_builtins.bool]] = None,
                 skip_instance_ready_poll: Optional[pulumi.Input[_builtins.bool]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 ua_prefix: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[_builtins.str] api_ca_path: The path to a Linode API CA file to trust.
        :param pulumi.Input[_builtins.str] api_version: The version of Linode API.
        :param pulumi.Input[_builtins.str] config_path: The path to the Linode config file to use. (default `~/.config/linode`)
        :param pulumi.Input[_builtins.str] config_profile: The Linode config profile to use. (default `default`)
        :param pulumi.Input[_builtins.bool] disable_internal_cache: Disable the internal caching system that backs certain Linode API requests.
        :param pulumi.Input[_builtins.int] event_poll_ms: The rate in milliseconds to poll for events.
        :param pulumi.Input[_builtins.int] lke_event_poll_ms: The rate in milliseconds to poll for LKE events.
        :param pulumi.Input[_builtins.int] lke_node_ready_poll_ms: The rate in milliseconds to poll for an LKE node to be ready.
        :param pulumi.Input[_builtins.int] max_retry_delay_ms: Maximum delay in milliseconds before retrying a request.
        :param pulumi.Input[_builtins.int] min_retry_delay_ms: Minimum delay in milliseconds before retrying a request.
        :param pulumi.Input[_builtins.str] obj_access_key: The access key to be used in ObjectStorageBucket and linode_object_storage_object.
        :param pulumi.Input[_builtins.bool] obj_bucket_force_delete: If true, when deleting a ObjectStorageBucket any objects and versions will be force deleted.
        :param pulumi.Input[_builtins.str] obj_secret_key: The secret key to be used in ObjectStorageBucket and linode_object_storage_object.
        :param pulumi.Input[_builtins.bool] obj_use_temp_keys: If true, temporary object keys will be created implicitly at apply-time for the ObjectStorageObject and linode_object_sorage_bucket resource.
        :param pulumi.Input[_builtins.bool] skip_implicit_reboots: If true, Linode Instances will not be rebooted on config and interface changes.
        :param pulumi.Input[_builtins.bool] skip_instance_delete_poll: Skip waiting for a Instance resource to finish deleting.
        :param pulumi.Input[_builtins.bool] skip_instance_ready_poll: Skip waiting for a Instance resource to be running.
        :param pulumi.Input[_builtins.str] token: The token that allows you access to your Linode account
        :param pulumi.Input[_builtins.str] ua_prefix: An HTTP User-Agent Prefix to prepend in API requests.
        :param pulumi.Input[_builtins.str] url: The HTTP(S) API address of the Linode API to use.
        """
        if api_ca_path is not None:
            pulumi.set(__self__, "api_ca_path", api_ca_path)
        if api_version is None:
            api_version = _utilities.get_env('LINODE_API_VERSION')
        if api_version is not None:
            pulumi.set(__self__, "api_version", api_version)
        if config_path is not None:
            pulumi.set(__self__, "config_path", config_path)
        if config_profile is not None:
            pulumi.set(__self__, "config_profile", config_profile)
        if disable_internal_cache is not None:
            pulumi.set(__self__, "disable_internal_cache", disable_internal_cache)
        if event_poll_ms is not None:
            pulumi.set(__self__, "event_poll_ms", event_poll_ms)
        if lke_event_poll_ms is not None:
            pulumi.set(__self__, "lke_event_poll_ms", lke_event_poll_ms)
        if lke_node_ready_poll_ms is not None:
            pulumi.set(__self__, "lke_node_ready_poll_ms", lke_node_ready_poll_ms)
        if max_retry_delay_ms is not None:
            pulumi.set(__self__, "max_retry_delay_ms", max_retry_delay_ms)
        if min_retry_delay_ms is not None:
            pulumi.set(__self__, "min_retry_delay_ms", min_retry_delay_ms)
        if obj_access_key is not None:
            pulumi.set(__self__, "obj_access_key", obj_access_key)
        if obj_bucket_force_delete is not None:
            pulumi.set(__self__, "obj_bucket_force_delete", obj_bucket_force_delete)
        if obj_secret_key is not None:
            pulumi.set(__self__, "obj_secret_key", obj_secret_key)
        if obj_use_temp_keys is not None:
            pulumi.set(__self__, "obj_use_temp_keys", obj_use_temp_keys)
        if skip_implicit_reboots is not None:
            pulumi.set(__self__, "skip_implicit_reboots", skip_implicit_reboots)
        if skip_instance_delete_poll is not None:
            pulumi.set(__self__, "skip_instance_delete_poll", skip_instance_delete_poll)
        if skip_instance_ready_poll is not None:
            pulumi.set(__self__, "skip_instance_ready_poll", skip_instance_ready_poll)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if ua_prefix is None:
            ua_prefix = _utilities.get_env('LINODE_UA_PREFIX')
        if ua_prefix is not None:
            pulumi.set(__self__, "ua_prefix", ua_prefix)
        if url is None:
            url = _utilities.get_env('LINODE_URL')
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter(name="apiCaPath")
    def api_ca_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path to a Linode API CA file to trust.
        """
        return pulumi.get(self, "api_ca_path")

    @api_ca_path.setter
    def api_ca_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_ca_path", value)

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The version of Linode API.
        """
        return pulumi.get(self, "api_version")

    @api_version.setter
    def api_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_version", value)

    @_builtins.property
    @pulumi.getter(name="configPath")
    def config_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path to the Linode config file to use. (default `~/.config/linode`)
        """
        return pulumi.get(self, "config_path")

    @config_path.setter
    def config_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "config_path", value)

    @_builtins.property
    @pulumi.getter(name="configProfile")
    def config_profile(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Linode config profile to use. (default `default`)
        """
        return pulumi.get(self, "config_profile")

    @config_profile.setter
    def config_profile(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "config_profile", value)

    @_builtins.property
    @pulumi.getter(name="disableInternalCache")
    def disable_internal_cache(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable the internal caching system that backs certain Linode API requests.
        """
        return pulumi.get(self, "disable_internal_cache")

    @disable_internal_cache.setter
    def disable_internal_cache(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_internal_cache", value)

    @_builtins.property
    @pulumi.getter(name="eventPollMs")
    def event_poll_ms(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The rate in milliseconds to poll for events.
        """
        return pulumi.get(self, "event_poll_ms")

    @event_poll_ms.setter
    def event_poll_ms(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "event_poll_ms", value)

    @_builtins.property
    @pulumi.getter(name="lkeEventPollMs")
    def lke_event_poll_ms(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The rate in milliseconds to poll for LKE events.
        """
        return pulumi.get(self, "lke_event_poll_ms")

    @lke_event_poll_ms.setter
    def lke_event_poll_ms(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "lke_event_poll_ms", value)

    @_builtins.property
    @pulumi.getter(name="lkeNodeReadyPollMs")
    def lke_node_ready_poll_ms(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The rate in milliseconds to poll for an LKE node to be ready.
        """
        return pulumi.get(self, "lke_node_ready_poll_ms")

    @lke_node_ready_poll_ms.setter
    def lke_node_ready_poll_ms(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "lke_node_ready_poll_ms", value)

    @_builtins.property
    @pulumi.getter(name="maxRetryDelayMs")
    def max_retry_delay_ms(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum delay in milliseconds before retrying a request.
        """
        return pulumi.get(self, "max_retry_delay_ms")

    @max_retry_delay_ms.setter
    def max_retry_delay_ms(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_retry_delay_ms", value)

    @_builtins.property
    @pulumi.getter(name="minRetryDelayMs")
    def min_retry_delay_ms(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Minimum delay in milliseconds before retrying a request.
        """
        return pulumi.get(self, "min_retry_delay_ms")

    @min_retry_delay_ms.setter
    def min_retry_delay_ms(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "min_retry_delay_ms", value)

    @_builtins.property
    @pulumi.getter(name="objAccessKey")
    def obj_access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access key to be used in ObjectStorageBucket and linode_object_storage_object.
        """
        return pulumi.get(self, "obj_access_key")

    @obj_access_key.setter
    def obj_access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "obj_access_key", value)

    @_builtins.property
    @pulumi.getter(name="objBucketForceDelete")
    def obj_bucket_force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, when deleting a ObjectStorageBucket any objects and versions will be force deleted.
        """
        return pulumi.get(self, "obj_bucket_force_delete")

    @obj_bucket_force_delete.setter
    def obj_bucket_force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "obj_bucket_force_delete", value)

    @_builtins.property
    @pulumi.getter(name="objSecretKey")
    def obj_secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The secret key to be used in ObjectStorageBucket and linode_object_storage_object.
        """
        return pulumi.get(self, "obj_secret_key")

    @obj_secret_key.setter
    def obj_secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "obj_secret_key", value)

    @_builtins.property
    @pulumi.getter(name="objUseTempKeys")
    def obj_use_temp_keys(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, temporary object keys will be created implicitly at apply-time for the ObjectStorageObject and linode_object_sorage_bucket resource.
        """
        return pulumi.get(self, "obj_use_temp_keys")

    @obj_use_temp_keys.setter
    def obj_use_temp_keys(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "obj_use_temp_keys", value)

    @_builtins.property
    @pulumi.getter(name="skipImplicitReboots")
    def skip_implicit_reboots(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, Linode Instances will not be rebooted on config and interface changes.
        """
        return pulumi.get(self, "skip_implicit_reboots")

    @skip_implicit_reboots.setter
    def skip_implicit_reboots(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_implicit_reboots", value)

    @_builtins.property
    @pulumi.getter(name="skipInstanceDeletePoll")
    def skip_instance_delete_poll(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Skip waiting for a Instance resource to finish deleting.
        """
        return pulumi.get(self, "skip_instance_delete_poll")

    @skip_instance_delete_poll.setter
    def skip_instance_delete_poll(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_instance_delete_poll", value)

    @_builtins.property
    @pulumi.getter(name="skipInstanceReadyPoll")
    def skip_instance_ready_poll(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Skip waiting for a Instance resource to be running.
        """
        return pulumi.get(self, "skip_instance_ready_poll")

    @skip_instance_ready_poll.setter
    def skip_instance_ready_poll(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_instance_ready_poll", value)

    @_builtins.property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The token that allows you access to your Linode account
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token", value)

    @_builtins.property
    @pulumi.getter(name="uaPrefix")
    def ua_prefix(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        An HTTP User-Agent Prefix to prepend in API requests.
        """
        return pulumi.get(self, "ua_prefix")

    @ua_prefix.setter
    def ua_prefix(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ua_prefix", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The HTTP(S) API address of the Linode API to use.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("pulumi:providers:linode")
class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_ca_path: Optional[pulumi.Input[_builtins.str]] = None,
                 api_version: Optional[pulumi.Input[_builtins.str]] = None,
                 config_path: Optional[pulumi.Input[_builtins.str]] = None,
                 config_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_internal_cache: Optional[pulumi.Input[_builtins.bool]] = None,
                 event_poll_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 lke_event_poll_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 lke_node_ready_poll_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 max_retry_delay_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 min_retry_delay_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 obj_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 obj_bucket_force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 obj_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 obj_use_temp_keys: Optional[pulumi.Input[_builtins.bool]] = None,
                 skip_implicit_reboots: Optional[pulumi.Input[_builtins.bool]] = None,
                 skip_instance_delete_poll: Optional[pulumi.Input[_builtins.bool]] = None,
                 skip_instance_ready_poll: Optional[pulumi.Input[_builtins.bool]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 ua_prefix: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The provider type for the linode package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_ca_path: The path to a Linode API CA file to trust.
        :param pulumi.Input[_builtins.str] api_version: The version of Linode API.
        :param pulumi.Input[_builtins.str] config_path: The path to the Linode config file to use. (default `~/.config/linode`)
        :param pulumi.Input[_builtins.str] config_profile: The Linode config profile to use. (default `default`)
        :param pulumi.Input[_builtins.bool] disable_internal_cache: Disable the internal caching system that backs certain Linode API requests.
        :param pulumi.Input[_builtins.int] event_poll_ms: The rate in milliseconds to poll for events.
        :param pulumi.Input[_builtins.int] lke_event_poll_ms: The rate in milliseconds to poll for LKE events.
        :param pulumi.Input[_builtins.int] lke_node_ready_poll_ms: The rate in milliseconds to poll for an LKE node to be ready.
        :param pulumi.Input[_builtins.int] max_retry_delay_ms: Maximum delay in milliseconds before retrying a request.
        :param pulumi.Input[_builtins.int] min_retry_delay_ms: Minimum delay in milliseconds before retrying a request.
        :param pulumi.Input[_builtins.str] obj_access_key: The access key to be used in ObjectStorageBucket and linode_object_storage_object.
        :param pulumi.Input[_builtins.bool] obj_bucket_force_delete: If true, when deleting a ObjectStorageBucket any objects and versions will be force deleted.
        :param pulumi.Input[_builtins.str] obj_secret_key: The secret key to be used in ObjectStorageBucket and linode_object_storage_object.
        :param pulumi.Input[_builtins.bool] obj_use_temp_keys: If true, temporary object keys will be created implicitly at apply-time for the ObjectStorageObject and linode_object_sorage_bucket resource.
        :param pulumi.Input[_builtins.bool] skip_implicit_reboots: If true, Linode Instances will not be rebooted on config and interface changes.
        :param pulumi.Input[_builtins.bool] skip_instance_delete_poll: Skip waiting for a Instance resource to finish deleting.
        :param pulumi.Input[_builtins.bool] skip_instance_ready_poll: Skip waiting for a Instance resource to be running.
        :param pulumi.Input[_builtins.str] token: The token that allows you access to your Linode account
        :param pulumi.Input[_builtins.str] ua_prefix: An HTTP User-Agent Prefix to prepend in API requests.
        :param pulumi.Input[_builtins.str] url: The HTTP(S) API address of the Linode API to use.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the linode package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_ca_path: Optional[pulumi.Input[_builtins.str]] = None,
                 api_version: Optional[pulumi.Input[_builtins.str]] = None,
                 config_path: Optional[pulumi.Input[_builtins.str]] = None,
                 config_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_internal_cache: Optional[pulumi.Input[_builtins.bool]] = None,
                 event_poll_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 lke_event_poll_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 lke_node_ready_poll_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 max_retry_delay_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 min_retry_delay_ms: Optional[pulumi.Input[_builtins.int]] = None,
                 obj_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 obj_bucket_force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 obj_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 obj_use_temp_keys: Optional[pulumi.Input[_builtins.bool]] = None,
                 skip_implicit_reboots: Optional[pulumi.Input[_builtins.bool]] = None,
                 skip_instance_delete_poll: Optional[pulumi.Input[_builtins.bool]] = None,
                 skip_instance_ready_poll: Optional[pulumi.Input[_builtins.bool]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 ua_prefix: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["api_ca_path"] = api_ca_path
            if api_version is None:
                api_version = _utilities.get_env('LINODE_API_VERSION')
            __props__.__dict__["api_version"] = api_version
            __props__.__dict__["config_path"] = config_path
            __props__.__dict__["config_profile"] = config_profile
            __props__.__dict__["disable_internal_cache"] = pulumi.Output.from_input(disable_internal_cache).apply(pulumi.runtime.to_json) if disable_internal_cache is not None else None
            __props__.__dict__["event_poll_ms"] = pulumi.Output.from_input(event_poll_ms).apply(pulumi.runtime.to_json) if event_poll_ms is not None else None
            __props__.__dict__["lke_event_poll_ms"] = pulumi.Output.from_input(lke_event_poll_ms).apply(pulumi.runtime.to_json) if lke_event_poll_ms is not None else None
            __props__.__dict__["lke_node_ready_poll_ms"] = pulumi.Output.from_input(lke_node_ready_poll_ms).apply(pulumi.runtime.to_json) if lke_node_ready_poll_ms is not None else None
            __props__.__dict__["max_retry_delay_ms"] = pulumi.Output.from_input(max_retry_delay_ms).apply(pulumi.runtime.to_json) if max_retry_delay_ms is not None else None
            __props__.__dict__["min_retry_delay_ms"] = pulumi.Output.from_input(min_retry_delay_ms).apply(pulumi.runtime.to_json) if min_retry_delay_ms is not None else None
            __props__.__dict__["obj_access_key"] = obj_access_key
            __props__.__dict__["obj_bucket_force_delete"] = pulumi.Output.from_input(obj_bucket_force_delete).apply(pulumi.runtime.to_json) if obj_bucket_force_delete is not None else None
            __props__.__dict__["obj_secret_key"] = None if obj_secret_key is None else pulumi.Output.secret(obj_secret_key)
            __props__.__dict__["obj_use_temp_keys"] = pulumi.Output.from_input(obj_use_temp_keys).apply(pulumi.runtime.to_json) if obj_use_temp_keys is not None else None
            __props__.__dict__["skip_implicit_reboots"] = pulumi.Output.from_input(skip_implicit_reboots).apply(pulumi.runtime.to_json) if skip_implicit_reboots is not None else None
            __props__.__dict__["skip_instance_delete_poll"] = pulumi.Output.from_input(skip_instance_delete_poll).apply(pulumi.runtime.to_json) if skip_instance_delete_poll is not None else None
            __props__.__dict__["skip_instance_ready_poll"] = pulumi.Output.from_input(skip_instance_ready_poll).apply(pulumi.runtime.to_json) if skip_instance_ready_poll is not None else None
            __props__.__dict__["token"] = token
            if ua_prefix is None:
                ua_prefix = _utilities.get_env('LINODE_UA_PREFIX')
            __props__.__dict__["ua_prefix"] = ua_prefix
            if url is None:
                url = _utilities.get_env('LINODE_URL')
            __props__.__dict__["url"] = url
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["objSecretKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Provider, __self__).__init__(
            'linode',
            resource_name,
            __props__,
            opts)

    @_builtins.property
    @pulumi.getter(name="apiCaPath")
    def api_ca_path(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The path to a Linode API CA file to trust.
        """
        return pulumi.get(self, "api_ca_path")

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The version of Linode API.
        """
        return pulumi.get(self, "api_version")

    @_builtins.property
    @pulumi.getter(name="configPath")
    def config_path(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The path to the Linode config file to use. (default `~/.config/linode`)
        """
        return pulumi.get(self, "config_path")

    @_builtins.property
    @pulumi.getter(name="configProfile")
    def config_profile(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The Linode config profile to use. (default `default`)
        """
        return pulumi.get(self, "config_profile")

    @_builtins.property
    @pulumi.getter(name="objAccessKey")
    def obj_access_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The access key to be used in ObjectStorageBucket and linode_object_storage_object.
        """
        return pulumi.get(self, "obj_access_key")

    @_builtins.property
    @pulumi.getter(name="objSecretKey")
    def obj_secret_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The secret key to be used in ObjectStorageBucket and linode_object_storage_object.
        """
        return pulumi.get(self, "obj_secret_key")

    @_builtins.property
    @pulumi.getter
    def token(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The token that allows you access to your Linode account
        """
        return pulumi.get(self, "token")

    @_builtins.property
    @pulumi.getter(name="uaPrefix")
    def ua_prefix(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        An HTTP User-Agent Prefix to prepend in API requests.
        """
        return pulumi.get(self, "ua_prefix")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The HTTP(S) API address of the Linode API to use.
        """
        return pulumi.get(self, "url")

    @pulumi.output_type
    class TerraformConfigResult:
        def __init__(__self__, result=None):
            if result and not isinstance(result, dict):
                raise TypeError("Expected argument 'result' to be a dict")
            pulumi.set(__self__, "result", result)

        @_builtins.property
        @pulumi.getter
        def result(self) -> Mapping[str, Any]:
            return pulumi.get(self, "result")

    def terraform_config(__self__) -> pulumi.Output['Provider.TerraformConfigResult']:
        """
        This function returns a Terraform config object with terraform-namecased keys,to be used with the Terraform Module Provider.
        """
        __args__ = dict()
        __args__['__self__'] = __self__
        return pulumi.runtime.call('pulumi:providers:linode/terraformConfig', __args__, res=__self__, typ=Provider.TerraformConfigResult)




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetLkeTypesResult',
    'AwaitableGetLkeTypesResult',
    'get_lke_types',
    'get_lke_types_output',
]

@pulumi.output_type
class GetLkeTypesResult:
    """
    A collection of values returned by getLkeTypes.
    """
    def __init__(__self__, filters=None, id=None, order=None, order_by=None, types=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if order and not isinstance(order, str):
            raise TypeError("Expected argument 'order' to be a str")
        pulumi.set(__self__, "order", order)
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        pulumi.set(__self__, "order_by", order_by)
        if types and not isinstance(types, list):
            raise TypeError("Expected argument 'types' to be a list")
        pulumi.set(__self__, "types", types)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetLkeTypesFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID representing the Kubernetes type.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def order(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order")

    @_builtins.property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order_by")

    @_builtins.property
    @pulumi.getter
    def types(self) -> Optional[Sequence['outputs.GetLkeTypesTypeResult']]:
        return pulumi.get(self, "types")


class AwaitableGetLkeTypesResult(GetLkeTypesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLkeTypesResult(
            filters=self.filters,
            id=self.id,
            order=self.order,
            order_by=self.order_by,
            types=self.types)


def get_lke_types(filters: Optional[Sequence[Union['GetLkeTypesFilterArgs', 'GetLkeTypesFilterArgsDict']]] = None,
                  order: Optional[_builtins.str] = None,
                  order_by: Optional[_builtins.str] = None,
                  types: Optional[Sequence[Union['GetLkeTypesTypeArgs', 'GetLkeTypesTypeArgsDict']]] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLkeTypesResult:
    """
    Provides information about Linode LKE types that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-lke-types).


    :param _builtins.str order: The order in which results should be returned. (`asc`, `desc`; default `asc`)
    :param _builtins.str order_by: The attribute to order the results by. See the Filterable Fields section for a list of valid fields.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['order'] = order
    __args__['orderBy'] = order_by
    __args__['types'] = types
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getLkeTypes:getLkeTypes', __args__, opts=opts, typ=GetLkeTypesResult).value

    return AwaitableGetLkeTypesResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        order=pulumi.get(__ret__, 'order'),
        order_by=pulumi.get(__ret__, 'order_by'),
        types=pulumi.get(__ret__, 'types'))
def get_lke_types_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetLkeTypesFilterArgs', 'GetLkeTypesFilterArgsDict']]]]] = None,
                         order: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         order_by: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         types: Optional[pulumi.Input[Optional[Sequence[Union['GetLkeTypesTypeArgs', 'GetLkeTypesTypeArgsDict']]]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLkeTypesResult]:
    """
    Provides information about Linode LKE types that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-lke-types).


    :param _builtins.str order: The order in which results should be returned. (`asc`, `desc`; default `asc`)
    :param _builtins.str order_by: The attribute to order the results by. See the Filterable Fields section for a list of valid fields.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['order'] = order
    __args__['orderBy'] = order_by
    __args__['types'] = types
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getLkeTypes:getLkeTypes', __args__, opts=opts, typ=GetLkeTypesResult)
    return __ret__.apply(lambda __response__: GetLkeTypesResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        order=pulumi.get(__response__, 'order'),
        order_by=pulumi.get(__response__, 'order_by'),
        types=pulumi.get(__response__, 'types')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetObjectStorageQuotaResult',
    'AwaitableGetObjectStorageQuotaResult',
    'get_object_storage_quota',
    'get_object_storage_quota_output',
]

@pulumi.output_type
class GetObjectStorageQuotaResult:
    """
    A collection of values returned by getObjectStorageQuota.
    """
    def __init__(__self__, description=None, endpoint_type=None, id=None, quota_id=None, quota_limit=None, quota_name=None, quota_usage=None, resource_metric=None, s3_endpoint=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if endpoint_type and not isinstance(endpoint_type, str):
            raise TypeError("Expected argument 'endpoint_type' to be a str")
        pulumi.set(__self__, "endpoint_type", endpoint_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if quota_id and not isinstance(quota_id, str):
            raise TypeError("Expected argument 'quota_id' to be a str")
        pulumi.set(__self__, "quota_id", quota_id)
        if quota_limit and not isinstance(quota_limit, int):
            raise TypeError("Expected argument 'quota_limit' to be a int")
        pulumi.set(__self__, "quota_limit", quota_limit)
        if quota_name and not isinstance(quota_name, str):
            raise TypeError("Expected argument 'quota_name' to be a str")
        pulumi.set(__self__, "quota_name", quota_name)
        if quota_usage and not isinstance(quota_usage, dict):
            raise TypeError("Expected argument 'quota_usage' to be a dict")
        pulumi.set(__self__, "quota_usage", quota_usage)
        if resource_metric and not isinstance(resource_metric, str):
            raise TypeError("Expected argument 'resource_metric' to be a str")
        pulumi.set(__self__, "resource_metric", resource_metric)
        if s3_endpoint and not isinstance(s3_endpoint, str):
            raise TypeError("Expected argument 's3_endpoint' to be a str")
        pulumi.set(__self__, "s3_endpoint", s3_endpoint)

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of the Object Storage quota.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> _builtins.str:
        """
        The type of the S3 endpoint of the Object Storage.
        """
        return pulumi.get(self, "endpoint_type")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique ID of the Object Storage quota data source.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="quotaId")
    def quota_id(self) -> _builtins.str:
        return pulumi.get(self, "quota_id")

    @_builtins.property
    @pulumi.getter(name="quotaLimit")
    def quota_limit(self) -> _builtins.int:
        """
        The maximum quantity allowed by the quota.
        """
        return pulumi.get(self, "quota_limit")

    @_builtins.property
    @pulumi.getter(name="quotaName")
    def quota_name(self) -> _builtins.str:
        """
        The name of the Object Storage quota.
        """
        return pulumi.get(self, "quota_name")

    @_builtins.property
    @pulumi.getter(name="quotaUsage")
    def quota_usage(self) -> 'outputs.GetObjectStorageQuotaQuotaUsageResult':
        """
        The usage data for a specific Object Storage related quota on your account. For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-object-storage-quota-usage).
        """
        return pulumi.get(self, "quota_usage")

    @_builtins.property
    @pulumi.getter(name="resourceMetric")
    def resource_metric(self) -> _builtins.str:
        """
        The specific Object Storage resource for the quota.
        """
        return pulumi.get(self, "resource_metric")

    @_builtins.property
    @pulumi.getter(name="s3Endpoint")
    def s3_endpoint(self) -> _builtins.str:
        """
        The S3 endpoint URL of the Object Storage, based on the `endpoint_type` and `region`.
        """
        return pulumi.get(self, "s3_endpoint")


class AwaitableGetObjectStorageQuotaResult(GetObjectStorageQuotaResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetObjectStorageQuotaResult(
            description=self.description,
            endpoint_type=self.endpoint_type,
            id=self.id,
            quota_id=self.quota_id,
            quota_limit=self.quota_limit,
            quota_name=self.quota_name,
            quota_usage=self.quota_usage,
            resource_metric=self.resource_metric,
            s3_endpoint=self.s3_endpoint)


def get_object_storage_quota(quota_id: Optional[_builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetObjectStorageQuotaResult:
    """
    Provides details about Object Storage quota information on your account.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-object-storage-quota).

    ## Example Usage

    The following example shows how one might use this data source to access information about an Object Storage quota.

    ```python
    import pulumi
    import pulumi_linode as linode

    my_quota = linode.get_object_storage_quota(quota_id="obj-buckets-br-gru-1.linodeobjects.com")
    ```


    :param _builtins.str quota_id: The Object Storage quota ID.
    """
    __args__ = dict()
    __args__['quotaId'] = quota_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getObjectStorageQuota:getObjectStorageQuota', __args__, opts=opts, typ=GetObjectStorageQuotaResult).value

    return AwaitableGetObjectStorageQuotaResult(
        description=pulumi.get(__ret__, 'description'),
        endpoint_type=pulumi.get(__ret__, 'endpoint_type'),
        id=pulumi.get(__ret__, 'id'),
        quota_id=pulumi.get(__ret__, 'quota_id'),
        quota_limit=pulumi.get(__ret__, 'quota_limit'),
        quota_name=pulumi.get(__ret__, 'quota_name'),
        quota_usage=pulumi.get(__ret__, 'quota_usage'),
        resource_metric=pulumi.get(__ret__, 'resource_metric'),
        s3_endpoint=pulumi.get(__ret__, 's3_endpoint'))
def get_object_storage_quota_output(quota_id: Optional[pulumi.Input[_builtins.str]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetObjectStorageQuotaResult]:
    """
    Provides details about Object Storage quota information on your account.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-object-storage-quota).

    ## Example Usage

    The following example shows how one might use this data source to access information about an Object Storage quota.

    ```python
    import pulumi
    import pulumi_linode as linode

    my_quota = linode.get_object_storage_quota(quota_id="obj-buckets-br-gru-1.linodeobjects.com")
    ```


    :param _builtins.str quota_id: The Object Storage quota ID.
    """
    __args__ = dict()
    __args__['quotaId'] = quota_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getObjectStorageQuota:getObjectStorageQuota', __args__, opts=opts, typ=GetObjectStorageQuotaResult)
    return __ret__.apply(lambda __response__: GetObjectStorageQuotaResult(
        description=pulumi.get(__response__, 'description'),
        endpoint_type=pulumi.get(__response__, 'endpoint_type'),
        id=pulumi.get(__response__, 'id'),
        quota_id=pulumi.get(__response__, 'quota_id'),
        quota_limit=pulumi.get(__response__, 'quota_limit'),
        quota_name=pulumi.get(__response__, 'quota_name'),
        quota_usage=pulumi.get(__response__, 'quota_usage'),
        resource_metric=pulumi.get(__response__, 'resource_metric'),
        s3_endpoint=pulumi.get(__response__, 's3_endpoint')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetPlacementGroupResult',
    'AwaitableGetPlacementGroupResult',
    'get_placement_group',
    'get_placement_group_output',
]

@pulumi.output_type
class GetPlacementGroupResult:
    """
    A collection of values returned by getPlacementGroup.
    """
    def __init__(__self__, id=None, is_compliant=None, label=None, members=None, migrations=None, placement_group_policy=None, placement_group_type=None, region=None):
        if id and not isinstance(id, int):
            raise TypeError("Expected argument 'id' to be a int")
        pulumi.set(__self__, "id", id)
        if is_compliant and not isinstance(is_compliant, bool):
            raise TypeError("Expected argument 'is_compliant' to be a bool")
        pulumi.set(__self__, "is_compliant", is_compliant)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        pulumi.set(__self__, "members", members)
        if migrations and not isinstance(migrations, dict):
            raise TypeError("Expected argument 'migrations' to be a dict")
        pulumi.set(__self__, "migrations", migrations)
        if placement_group_policy and not isinstance(placement_group_policy, str):
            raise TypeError("Expected argument 'placement_group_policy' to be a str")
        pulumi.set(__self__, "placement_group_policy", placement_group_policy)
        if placement_group_type and not isinstance(placement_group_type, str):
            raise TypeError("Expected argument 'placement_group_type' to be a str")
        pulumi.set(__self__, "placement_group_type", placement_group_type)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.int:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isCompliant")
    def is_compliant(self) -> _builtins.bool:
        """
        Whether this Linode is currently compliant with the group's placement group type.
        """
        return pulumi.get(self, "is_compliant")

    @_builtins.property
    @pulumi.getter
    def label(self) -> _builtins.str:
        """
        The label of the Placement Group. This field can only contain ASCII letters, digits and dashes.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter
    def members(self) -> Optional[Sequence['outputs.GetPlacementGroupMemberResult']]:
        """
        A set of Linodes currently assigned to this Placement Group.
        """
        return pulumi.get(self, "members")

    @_builtins.property
    @pulumi.getter
    def migrations(self) -> Optional['outputs.GetPlacementGroupMigrationsResult']:
        """
        Any Linodes that are being migrated to or from the placement group.
        """
        return pulumi.get(self, "migrations")

    @_builtins.property
    @pulumi.getter(name="placementGroupPolicy")
    def placement_group_policy(self) -> _builtins.str:
        """
        Whether Linodes must be able to become compliant during assignment. (Default `strict`)
        """
        return pulumi.get(self, "placement_group_policy")

    @_builtins.property
    @pulumi.getter(name="placementGroupType")
    def placement_group_type(self) -> _builtins.str:
        """
        The placement group type to use when placing Linodes in this group.
        """
        return pulumi.get(self, "placement_group_type")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The region of the Placement Group.
        """
        return pulumi.get(self, "region")


class AwaitableGetPlacementGroupResult(GetPlacementGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPlacementGroupResult(
            id=self.id,
            is_compliant=self.is_compliant,
            label=self.label,
            members=self.members,
            migrations=self.migrations,
            placement_group_policy=self.placement_group_policy,
            placement_group_type=self.placement_group_type,
            region=self.region)


def get_placement_group(id: Optional[_builtins.int] = None,
                        members: Optional[Sequence[Union['GetPlacementGroupMemberArgs', 'GetPlacementGroupMemberArgsDict']]] = None,
                        migrations: Optional[Union['GetPlacementGroupMigrationsArgs', 'GetPlacementGroupMigrationsArgsDict']] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPlacementGroupResult:
    """
    `PlacementGroup` provides details about a Linode placement group.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-placement-group).

    ## Example Usage

    The following example shows how the resource might be used to obtain additional information about a Linode placement group.

    ```python
    import pulumi
    import pulumi_linode as linode

    pg = linode.get_placement_group(id=12345)
    ```


    :param _builtins.int id: The ID of the Placement Group.
    :param Sequence[Union['GetPlacementGroupMemberArgs', 'GetPlacementGroupMemberArgsDict']] members: A set of Linodes currently assigned to this Placement Group.
    :param Union['GetPlacementGroupMigrationsArgs', 'GetPlacementGroupMigrationsArgsDict'] migrations: Any Linodes that are being migrated to or from the placement group.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['members'] = members
    __args__['migrations'] = migrations
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getPlacementGroup:getPlacementGroup', __args__, opts=opts, typ=GetPlacementGroupResult).value

    return AwaitableGetPlacementGroupResult(
        id=pulumi.get(__ret__, 'id'),
        is_compliant=pulumi.get(__ret__, 'is_compliant'),
        label=pulumi.get(__ret__, 'label'),
        members=pulumi.get(__ret__, 'members'),
        migrations=pulumi.get(__ret__, 'migrations'),
        placement_group_policy=pulumi.get(__ret__, 'placement_group_policy'),
        placement_group_type=pulumi.get(__ret__, 'placement_group_type'),
        region=pulumi.get(__ret__, 'region'))
def get_placement_group_output(id: Optional[pulumi.Input[_builtins.int]] = None,
                               members: Optional[pulumi.Input[Optional[Sequence[Union['GetPlacementGroupMemberArgs', 'GetPlacementGroupMemberArgsDict']]]]] = None,
                               migrations: Optional[pulumi.Input[Optional[Union['GetPlacementGroupMigrationsArgs', 'GetPlacementGroupMigrationsArgsDict']]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPlacementGroupResult]:
    """
    `PlacementGroup` provides details about a Linode placement group.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-placement-group).

    ## Example Usage

    The following example shows how the resource might be used to obtain additional information about a Linode placement group.

    ```python
    import pulumi
    import pulumi_linode as linode

    pg = linode.get_placement_group(id=12345)
    ```


    :param _builtins.int id: The ID of the Placement Group.
    :param Sequence[Union['GetPlacementGroupMemberArgs', 'GetPlacementGroupMemberArgsDict']] members: A set of Linodes currently assigned to this Placement Group.
    :param Union['GetPlacementGroupMigrationsArgs', 'GetPlacementGroupMigrationsArgsDict'] migrations: Any Linodes that are being migrated to or from the placement group.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['members'] = members
    __args__['migrations'] = migrations
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getPlacementGroup:getPlacementGroup', __args__, opts=opts, typ=GetPlacementGroupResult)
    return __ret__.apply(lambda __response__: GetPlacementGroupResult(
        id=pulumi.get(__response__, 'id'),
        is_compliant=pulumi.get(__response__, 'is_compliant'),
        label=pulumi.get(__response__, 'label'),
        members=pulumi.get(__response__, 'members'),
        migrations=pulumi.get(__response__, 'migrations'),
        placement_group_policy=pulumi.get(__response__, 'placement_group_policy'),
        placement_group_type=pulumi.get(__response__, 'placement_group_type'),
        region=pulumi.get(__response__, 'region')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetObjectStorageClusterResult',
    'AwaitableGetObjectStorageClusterResult',
    'get_object_storage_cluster',
    'get_object_storage_cluster_output',
]

@pulumi.output_type
class GetObjectStorageClusterResult:
    """
    A collection of values returned by getObjectStorageCluster.
    """
    def __init__(__self__, domain=None, id=None, region=None, static_site_domain=None, status=None):
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if static_site_domain and not isinstance(static_site_domain, str):
            raise TypeError("Expected argument 'static_site_domain' to be a str")
        pulumi.set(__self__, "static_site_domain", static_site_domain)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> _builtins.str:
        """
        The base URL for this cluster.
        """
        return pulumi.get(self, "domain")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The region this cluster is located in. See all regions [here](https://api.linode.com/v4/regions).
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="staticSiteDomain")
    def static_site_domain(self) -> _builtins.str:
        """
        The base URL for this cluster used when hosting static sites.
        """
        return pulumi.get(self, "static_site_domain")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        This cluster's status. (`available`, `unavailable`)
        """
        return pulumi.get(self, "status")


class AwaitableGetObjectStorageClusterResult(GetObjectStorageClusterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetObjectStorageClusterResult(
            domain=self.domain,
            id=self.id,
            region=self.region,
            static_site_domain=self.static_site_domain,
            status=self.status)


def get_object_storage_cluster(id: Optional[_builtins.str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetObjectStorageClusterResult:
    """
    Provides information about a Linode Object Storage Cluster
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-object-storage-cluster).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode Object Storage Cluster.

    ```python
    import pulumi
    import pulumi_linode as linode

    primary = linode.get_object_storage_cluster(id="us-east-1")
    ```


    :param _builtins.str id: The unique ID of this cluster.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getObjectStorageCluster:getObjectStorageCluster', __args__, opts=opts, typ=GetObjectStorageClusterResult).value

    return AwaitableGetObjectStorageClusterResult(
        domain=pulumi.get(__ret__, 'domain'),
        id=pulumi.get(__ret__, 'id'),
        region=pulumi.get(__ret__, 'region'),
        static_site_domain=pulumi.get(__ret__, 'static_site_domain'),
        status=pulumi.get(__ret__, 'status'))
def get_object_storage_cluster_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetObjectStorageClusterResult]:
    """
    Provides information about a Linode Object Storage Cluster
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-object-storage-cluster).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode Object Storage Cluster.

    ```python
    import pulumi
    import pulumi_linode as linode

    primary = linode.get_object_storage_cluster(id="us-east-1")
    ```


    :param _builtins.str id: The unique ID of this cluster.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getObjectStorageCluster:getObjectStorageCluster', __args__, opts=opts, typ=GetObjectStorageClusterResult)
    return __ret__.apply(lambda __response__: GetObjectStorageClusterResult(
        domain=pulumi.get(__response__, 'domain'),
        id=pulumi.get(__response__, 'id'),
        region=pulumi.get(__response__, 'region'),
        static_site_domain=pulumi.get(__response__, 'static_site_domain'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRegionsResult',
    'AwaitableGetRegionsResult',
    'get_regions',
    'get_regions_output',
]

@pulumi.output_type
class GetRegionsResult:
    """
    A collection of values returned by getRegions.
    """
    def __init__(__self__, filters=None, id=None, regions=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetRegionsFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def regions(self) -> Optional[Sequence['outputs.GetRegionsRegionResult']]:
        return pulumi.get(self, "regions")


class AwaitableGetRegionsResult(GetRegionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRegionsResult(
            filters=self.filters,
            id=self.id,
            regions=self.regions)


def get_regions(filters: Optional[Sequence[Union['GetRegionsFilterArgs', 'GetRegionsFilterArgsDict']]] = None,
                regions: Optional[Sequence[Union['GetRegionsRegionArgs', 'GetRegionsRegionArgsDict']]] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRegionsResult:
    """
    Provides information about Linode regions that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-regions).

    ```python
    import pulumi
    import pulumi_linode as linode

    filtered_regions = linode.get_regions(filters=[
        {
            "name": "status",
            "values": ["ok"],
        },
        {
            "name": "capabilities",
            "values": ["NodeBalancers"],
        },
    ])
    pulumi.export("regions", filtered_regions.regions)
    ```

    ## Filterable Fields

    * `status`

    * `country`

    * `capabilities`

    * `site_type`
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['regions'] = regions
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getRegions:getRegions', __args__, opts=opts, typ=GetRegionsResult).value

    return AwaitableGetRegionsResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        regions=pulumi.get(__ret__, 'regions'))
def get_regions_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetRegionsFilterArgs', 'GetRegionsFilterArgsDict']]]]] = None,
                       regions: Optional[pulumi.Input[Optional[Sequence[Union['GetRegionsRegionArgs', 'GetRegionsRegionArgsDict']]]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRegionsResult]:
    """
    Provides information about Linode regions that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-regions).

    ```python
    import pulumi
    import pulumi_linode as linode

    filtered_regions = linode.get_regions(filters=[
        {
            "name": "status",
            "values": ["ok"],
        },
        {
            "name": "capabilities",
            "values": ["NodeBalancers"],
        },
    ])
    pulumi.export("regions", filtered_regions.regions)
    ```

    ## Filterable Fields

    * `status`

    * `country`

    * `capabilities`

    * `site_type`
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['regions'] = regions
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getRegions:getRegions', __args__, opts=opts, typ=GetRegionsResult)
    return __ret__.apply(lambda __response__: GetRegionsResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        regions=pulumi.get(__response__, 'regions')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetDomainZonefileResult',
    'AwaitableGetDomainZonefileResult',
    'get_domain_zonefile',
    'get_domain_zonefile_output',
]

@pulumi.output_type
class GetDomainZonefileResult:
    """
    A collection of values returned by getDomainZonefile.
    """
    def __init__(__self__, domain_id=None, id=None, zone_files=None):
        if domain_id and not isinstance(domain_id, int):
            raise TypeError("Expected argument 'domain_id' to be a int")
        pulumi.set(__self__, "domain_id", domain_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if zone_files and not isinstance(zone_files, list):
            raise TypeError("Expected argument 'zone_files' to be a list")
        pulumi.set(__self__, "zone_files", zone_files)

    @_builtins.property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> _builtins.int:
        """
        The associated domain's unique ID.
        """
        return pulumi.get(self, "domain_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="zoneFiles")
    def zone_files(self) -> Sequence[_builtins.str]:
        """
        Array of strings representing the Domain Zonefile.
        """
        return pulumi.get(self, "zone_files")


class AwaitableGetDomainZonefileResult(GetDomainZonefileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDomainZonefileResult(
            domain_id=self.domain_id,
            id=self.id,
            zone_files=self.zone_files)


def get_domain_zonefile(domain_id: Optional[_builtins.int] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDomainZonefileResult:
    """
    Provides information about a Linode Domain Zonefile.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-domain-zone).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode Domain Zonefile.

    ```python
    import pulumi
    import pulumi_linode as linode

    my_zonefile = linode.get_domain_zonefile(domain_id=3150401)
    ```


    :param _builtins.int domain_id: The associated domain's unique ID.
    """
    __args__ = dict()
    __args__['domainId'] = domain_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getDomainZonefile:getDomainZonefile', __args__, opts=opts, typ=GetDomainZonefileResult).value

    return AwaitableGetDomainZonefileResult(
        domain_id=pulumi.get(__ret__, 'domain_id'),
        id=pulumi.get(__ret__, 'id'),
        zone_files=pulumi.get(__ret__, 'zone_files'))
def get_domain_zonefile_output(domain_id: Optional[pulumi.Input[_builtins.int]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDomainZonefileResult]:
    """
    Provides information about a Linode Domain Zonefile.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-domain-zone).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode Domain Zonefile.

    ```python
    import pulumi
    import pulumi_linode as linode

    my_zonefile = linode.get_domain_zonefile(domain_id=3150401)
    ```


    :param _builtins.int domain_id: The associated domain's unique ID.
    """
    __args__ = dict()
    __args__['domainId'] = domain_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getDomainZonefile:getDomainZonefile', __args__, opts=opts, typ=GetDomainZonefileResult)
    return __ret__.apply(lambda __response__: GetDomainZonefileResult(
        domain_id=pulumi.get(__response__, 'domain_id'),
        id=pulumi.get(__response__, 'id'),
        zone_files=pulumi.get(__response__, 'zone_files')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetFirewallSettingsResult',
    'AwaitableGetFirewallSettingsResult',
    'get_firewall_settings',
    'get_firewall_settings_output',
]

@pulumi.output_type
class GetFirewallSettingsResult:
    """
    A collection of values returned by getFirewallSettings.
    """
    def __init__(__self__, default_firewall_ids=None, id=None):
        if default_firewall_ids and not isinstance(default_firewall_ids, dict):
            raise TypeError("Expected argument 'default_firewall_ids' to be a dict")
        pulumi.set(__self__, "default_firewall_ids", default_firewall_ids)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter(name="defaultFirewallIds")
    def default_firewall_ids(self) -> 'outputs.GetFirewallSettingsDefaultFirewallIdsResult':
        return pulumi.get(self, "default_firewall_ids")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetFirewallSettingsResult(GetFirewallSettingsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFirewallSettingsResult(
            default_firewall_ids=self.default_firewall_ids,
            id=self.id)


def get_firewall_settings(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFirewallSettingsResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getFirewallSettings:getFirewallSettings', __args__, opts=opts, typ=GetFirewallSettingsResult).value

    return AwaitableGetFirewallSettingsResult(
        default_firewall_ids=pulumi.get(__ret__, 'default_firewall_ids'),
        id=pulumi.get(__ret__, 'id'))
def get_firewall_settings_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFirewallSettingsResult]:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getFirewallSettings:getFirewallSettings', __args__, opts=opts, typ=GetFirewallSettingsResult)
    return __ret__.apply(lambda __response__: GetFirewallSettingsResult(
        default_firewall_ids=pulumi.get(__response__, 'default_firewall_ids'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetNodebalancerConfigsResult',
    'AwaitableGetNodebalancerConfigsResult',
    'get_nodebalancer_configs',
    'get_nodebalancer_configs_output',
]

@pulumi.output_type
class GetNodebalancerConfigsResult:
    """
    A collection of values returned by getNodebalancerConfigs.
    """
    def __init__(__self__, filters=None, id=None, nodebalancer_configs=None, nodebalancer_id=None, order=None, order_by=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if nodebalancer_configs and not isinstance(nodebalancer_configs, list):
            raise TypeError("Expected argument 'nodebalancer_configs' to be a list")
        pulumi.set(__self__, "nodebalancer_configs", nodebalancer_configs)
        if nodebalancer_id and not isinstance(nodebalancer_id, int):
            raise TypeError("Expected argument 'nodebalancer_id' to be a int")
        pulumi.set(__self__, "nodebalancer_id", nodebalancer_id)
        if order and not isinstance(order, str):
            raise TypeError("Expected argument 'order' to be a str")
        pulumi.set(__self__, "order", order)
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        pulumi.set(__self__, "order_by", order_by)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetNodebalancerConfigsFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The config's ID.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="nodebalancerConfigs")
    def nodebalancer_configs(self) -> Optional[Sequence['outputs.GetNodebalancerConfigsNodebalancerConfigResult']]:
        return pulumi.get(self, "nodebalancer_configs")

    @_builtins.property
    @pulumi.getter(name="nodebalancerId")
    def nodebalancer_id(self) -> _builtins.int:
        """
        The ID of the NodeBalancer that contains the config.
        """
        return pulumi.get(self, "nodebalancer_id")

    @_builtins.property
    @pulumi.getter
    def order(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order")

    @_builtins.property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order_by")


class AwaitableGetNodebalancerConfigsResult(GetNodebalancerConfigsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNodebalancerConfigsResult(
            filters=self.filters,
            id=self.id,
            nodebalancer_configs=self.nodebalancer_configs,
            nodebalancer_id=self.nodebalancer_id,
            order=self.order,
            order_by=self.order_by)


def get_nodebalancer_configs(filters: Optional[Sequence[Union['GetNodebalancerConfigsFilterArgs', 'GetNodebalancerConfigsFilterArgsDict']]] = None,
                             nodebalancer_configs: Optional[Sequence[Union['GetNodebalancerConfigsNodebalancerConfigArgs', 'GetNodebalancerConfigsNodebalancerConfigArgsDict']]] = None,
                             nodebalancer_id: Optional[_builtins.int] = None,
                             order: Optional[_builtins.str] = None,
                             order_by: Optional[_builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNodebalancerConfigsResult:
    """
    Provides information about Linode NodeBalancer Configs that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-node-balancer-configs).

    ## Example Usage

    The following example shows how one might use this data source to access information about a list of NodeBalancer Configs.

    ```python
    import pulumi
    import pulumi_linode as linode

    filter_nb_configs = linode.get_nodebalancer_configs(nodebalancer_id=12345,
        filters=[{
            "name": "port",
            "values": ["80"],
        }])
    pulumi.export("nodebalancerConfigId", filter_nb_configs.nodebalancer_configs[0].id)
    ```

    ## Filterable Fields

    * `algorithm`

    * `check`

    * `nodebalancer_id`

    * `port`

    * `protocol`

    * `proxy_protocol`

    * `stickiness`

    * `check_path`

    * `check_body`

    * `check_passive`

    * `cipher_suite`

    * `ssl_commonname`


    :param _builtins.int nodebalancer_id: The ID of the NodeBalancer to access.
           
           * `filter` - (Optional) A set of filters used to select Linode NodeBalancers that meet certain requirements.
    :param _builtins.str order: The order in which results should be returned. (`asc`, `desc`; default `asc`)
    :param _builtins.str order_by: The attribute to order the results by. See the Filterable Fields section for a list of valid fields.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['nodebalancerConfigs'] = nodebalancer_configs
    __args__['nodebalancerId'] = nodebalancer_id
    __args__['order'] = order
    __args__['orderBy'] = order_by
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getNodebalancerConfigs:getNodebalancerConfigs', __args__, opts=opts, typ=GetNodebalancerConfigsResult).value

    return AwaitableGetNodebalancerConfigsResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        nodebalancer_configs=pulumi.get(__ret__, 'nodebalancer_configs'),
        nodebalancer_id=pulumi.get(__ret__, 'nodebalancer_id'),
        order=pulumi.get(__ret__, 'order'),
        order_by=pulumi.get(__ret__, 'order_by'))
def get_nodebalancer_configs_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetNodebalancerConfigsFilterArgs', 'GetNodebalancerConfigsFilterArgsDict']]]]] = None,
                                    nodebalancer_configs: Optional[pulumi.Input[Optional[Sequence[Union['GetNodebalancerConfigsNodebalancerConfigArgs', 'GetNodebalancerConfigsNodebalancerConfigArgsDict']]]]] = None,
                                    nodebalancer_id: Optional[pulumi.Input[_builtins.int]] = None,
                                    order: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    order_by: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNodebalancerConfigsResult]:
    """
    Provides information about Linode NodeBalancer Configs that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-node-balancer-configs).

    ## Example Usage

    The following example shows how one might use this data source to access information about a list of NodeBalancer Configs.

    ```python
    import pulumi
    import pulumi_linode as linode

    filter_nb_configs = linode.get_nodebalancer_configs(nodebalancer_id=12345,
        filters=[{
            "name": "port",
            "values": ["80"],
        }])
    pulumi.export("nodebalancerConfigId", filter_nb_configs.nodebalancer_configs[0].id)
    ```

    ## Filterable Fields

    * `algorithm`

    * `check`

    * `nodebalancer_id`

    * `port`

    * `protocol`

    * `proxy_protocol`

    * `stickiness`

    * `check_path`

    * `check_body`

    * `check_passive`

    * `cipher_suite`

    * `ssl_commonname`


    :param _builtins.int nodebalancer_id: The ID of the NodeBalancer to access.
           
           * `filter` - (Optional) A set of filters used to select Linode NodeBalancers that meet certain requirements.
    :param _builtins.str order: The order in which results should be returned. (`asc`, `desc`; default `asc`)
    :param _builtins.str order_by: The attribute to order the results by. See the Filterable Fields section for a list of valid fields.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['nodebalancerConfigs'] = nodebalancer_configs
    __args__['nodebalancerId'] = nodebalancer_id
    __args__['order'] = order
    __args__['orderBy'] = order_by
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getNodebalancerConfigs:getNodebalancerConfigs', __args__, opts=opts, typ=GetNodebalancerConfigsResult)
    return __ret__.apply(lambda __response__: GetNodebalancerConfigsResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        nodebalancer_configs=pulumi.get(__response__, 'nodebalancer_configs'),
        nodebalancer_id=pulumi.get(__response__, 'nodebalancer_id'),
        order=pulumi.get(__response__, 'order'),
        order_by=pulumi.get(__response__, 'order_by')))
